DirEntry

Struct DirEntry 

pub struct DirEntry { /* private fields */ }
A directory entry like std::fs::DirEntry.

Implementations

Source

impl DirEntry

pub fn path(&self) -> &Path

Returns the full path to the file that this entry represents.

The full path is created by joining the original path to WalkDir::new with the filename of this entry.

pub fn metadata(&self) -> Option<Metadata>

Return the metadata for the file that this entry points at.

pub fn file_type(&self) -> FileType

Return the file type for the file that this entry points at.

pub fn file_name(&self) -> &OsStr

Returns the bare file name of this directory entry without any other leading path component.

pub fn depth(&self) -> usize

Returns the depth at which this entry was created relative to the original path to WalkDir::new.