pub struct DirEntry { /* private fields */ }Expand description
A directory entry like std::fs::DirEntry.
Implementations
Sourceimpl DirEntry
impl DirEntry
Sourcepub fn path(&self) -> &Path
pub fn path(&self) -> &Path
Returns the full path to the file that this entry represents.
The full path is created by joining the original path to WalkDir::new with the filename of this entry.
Sourcepub fn metadata(&self) -> Option<Metadata>
pub fn metadata(&self) -> Option<Metadata>
Return the metadata for the file that this entry points at.
Sourcepub fn file_type(&self) -> FileType
pub fn file_type(&self) -> FileType
Return the file type for the file that this entry points at.